@@ -1,5 +1,10 @@
 var NAVTREEINDEX122 =
 {
+"structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#ad75a752c8505d85a57dc85be72c31cb9":[3,0,10,26,0,6,11],
+"structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#ad75a752c8505d85a57dc85be72c31cb9":[4,0,7,23,0,6,11],
+"structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#aecc4f4d8c0b0284a923d0e26ad3557f2":[3,0,10,26,0,6,15],
+"structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#aecc4f4d8c0b0284a923d0e26ad3557f2":[4,0,7,23,0,6,15],
+"structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#af1f962c57dbecd849d5367ebcebb66e1":[3,0,10,26,0,6,13],
 "structzypp_1_1misc_1_1testcase_1_1TestcaseSetupImpl.html#af1f962c57dbecd849d5367ebcebb66e1":[4,0,7,23,0,6,13],
 "structzypp_1_1misc_1_1testcase_1_1TestcaseTrial.html":[3,0,10,26,0,7],
 "structzypp_1_1misc_1_1testcase_1_1TestcaseTrial.html":[4,0,7,23,0,7],
@@ -244,10 +249,5 @@ var NAVTREEINDEX122 =
 "structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a22afdce6cb3554f33c7f0633fe04fe53":[3,0,10,32,2,0,1],
 "structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a22afdce6cb3554f33c7f0633fe04fe53":[4,0,7,27,1,0,1],
 "structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a480d4e6f86d8b862f752871f23f7c6f6":[3,0,10,32,2,0,5],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a480d4e6f86d8b862f752871f23f7c6f6":[4,0,7,27,1,0,5],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a59f8d7a74bb439d05f6c54db6e272d81":[3,0,10,32,2,0,6],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a59f8d7a74bb439d05f6c54db6e272d81":[4,0,7,27,1,0,6],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[3,0,10,32,2,0,3],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a6024d7def0b76f3f0e282c473a85d29a":[4,0,7,27,1,0,3],
-"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a6e56966dca0b1e147cfe474e43b898b2":[3,0,10,32,2,0,2]
+"structzypp_1_1repo_1_1DeltaCandidates_1_1Impl.html#a480d4e6f86d8b862f752871f23f7c6f6":[4,0,7,27,1,0,5]
 };
