@@ -1,5 +1,10 @@
 var NAVTREEINDEX125 =
 {
+"structzypp_1_1sat_1_1SolvableType.html#a2947aba00fbe3b68f82b6eac58213c30":[3,0,10,37,14,13],
+"structzypp_1_1sat_1_1SolvableType.html#a2947aba00fbe3b68f82b6eac58213c30":[4,0,7,31,15,13],
+"structzypp_1_1sat_1_1SolvableType.html#a2a2ae29115e39feb73c985a288209120":[3,0,10,37,14,38],
+"structzypp_1_1sat_1_1SolvableType.html#a2a2ae29115e39feb73c985a288209120":[4,0,7,31,15,38],
+"structzypp_1_1sat_1_1SolvableType.html#a2aaa4bc21653b25df56cd9247997573e":[3,0,10,37,14,11],
 "structzypp_1_1sat_1_1SolvableType.html#a2aaa4bc21653b25df56cd9247997573e":[4,0,7,31,15,11],
 "structzypp_1_1sat_1_1SolvableType.html#a2ac8fd6d5a386b166c76001a014643c7":[3,0,10,37,14,79],
 "structzypp_1_1sat_1_1SolvableType.html#a2ac8fd6d5a386b166c76001a014643c7":[4,0,7,31,15,79],
@@ -244,10 +249,5 @@ var NAVTREEINDEX125 =
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa7e218dcd2de60de1b756ade25948cb2":[3,0,10,37,17,1,17],
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa7e218dcd2de60de1b756ade25948cb2":[4,0,7,31,18,1,17],
 "structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa8cfd02c9d218ebeb31b05a300f238d7":[3,0,10,37,17,1,24],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa8cfd02c9d218ebeb31b05a300f238d7":[4,0,7,31,18,1,24],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa9d844842381e806c60f8fc7a47525af":[3,0,10,37,17,1,27],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa9d844842381e806c60f8fc7a47525af":[4,0,7,31,18,1,27],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#acc579da36562b9e3d9018ba825257e40":[3,0,10,37,17,1,16],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#acc579da36562b9e3d9018ba825257e40":[4,0,7,31,18,1,16],
-"structzypp_1_1sat_1_1Transaction_1_1Impl.html#ad32c90025d0fec112fbffadfa6770873":[3,0,10,37,17,1,15]
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#aa8cfd02c9d218ebeb31b05a300f238d7":[4,0,7,31,18,1,24]
 };
