@@ -1,5 +1,7 @@
 var NAVTREEINDEX41 =
 {
+"classzypp_1_1base_1_1LogControl.html#a8319233a0c13effdc0451e57cc375a90":[3,0,10,2,4,3],
+"classzypp_1_1base_1_1LogControl.html#a8319233a0c13effdc0451e57cc375a90":[4,0,7,1,3,3],
 "classzypp_1_1base_1_1LogControl.html#a8b129042adedbfbf5afb54c6214e42c4":[3,0,10,2,4,10],
 "classzypp_1_1base_1_1LogControl.html#a8b129042adedbfbf5afb54c6214e42c4":[4,0,7,1,3,10],
 "classzypp_1_1base_1_1LogControl.html#a8b1c079f7f326f5c17c0a27e57e70f58":[3,0,10,2,4,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX41 =
 "classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[3,0,10,3,1,35],
 "classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[4,0,7,2,1,35],
 "classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[3,0,10,3,1,10],
-"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[4,0,7,2,1,10],
-"classzypp_1_1bit_1_1BitField.html#ae1694ae9c2588b3908629d7d7b1a02ed":[3,0,10,3,1,12],
-"classzypp_1_1bit_1_1BitField.html#ae1694ae9c2588b3908629d7d7b1a02ed":[4,0,7,2,1,12]
+"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[4,0,7,2,1,10]
 };
