@@ -1,5 +1,7 @@
 var NAVTREEINDEX54 =
 {
+"classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[4,0,7,22,72,9],
+"classzypp_1_1media_1_1ProxyInfo.html#a528fd993cd7de980a8220a04f9f72b60":[3,0,10,25,72,3],
 "classzypp_1_1media_1_1ProxyInfo.html#a528fd993cd7de980a8220a04f9f72b60":[4,0,7,22,72,3],
 "classzypp_1_1media_1_1ProxyInfo.html#a6193b2a0628a0c6b2027dc2cd7e4f0d1":[3,0,10,25,72,1],
 "classzypp_1_1media_1_1ProxyInfo.html#a6193b2a0628a0c6b2027dc2cd7e4f0d1":[4,0,7,22,72,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX54 =
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[4,0,7,22,77,0,12],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[3,0,10,25,77,0,4],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[4,0,7,22,77,0,4],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[3,0,10,25,77,0,18],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[4,0,7,22,77,0,18],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ace59493de0b2b0337690d85d01584b66":[3,0,10,25,77,0,25]
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[3,0,10,25,77,0,18]
 };
