@@ -1,5 +1,7 @@
 var NAVTREEINDEX84 =
 {
+"classzyppng_1_1NetworkRequestPrivate.html#a8581fc2168a694f0882576c444d5dda1":[4,0,9,80,37],
+"classzyppng_1_1NetworkRequestPrivate.html#a9106c125ba80ba79ebeb7254cbdaeb45":[3,0,13,118,31],
 "classzyppng_1_1NetworkRequestPrivate.html#a9106c125ba80ba79ebeb7254cbdaeb45":[4,0,9,80,31],
 "classzyppng_1_1NetworkRequestPrivate.html#aa164d322b7c804a92bd2baac05501318":[3,0,13,118,12],
 "classzyppng_1_1NetworkRequestPrivate.html#aa164d322b7c804a92bd2baac05501318":[4,0,9,80,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX84 =
 "classzyppng_1_1ProgressObserverPrivate.html#a5e81e894a1af6bb5a4a332c5aff1b057":[4,0,9,87,15],
 "classzyppng_1_1ProgressObserverPrivate.html#a71b148b6f5ba37bcd2ea3005de65f715":[3,0,13,125,14],
 "classzyppng_1_1ProgressObserverPrivate.html#a71b148b6f5ba37bcd2ea3005de65f715":[4,0,9,87,14],
-"classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[3,0,13,125,25],
-"classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[4,0,9,87,25],
-"classzyppng_1_1ProgressObserverPrivate.html#a93fe8a114d0769cd08b295bb8f6f3029":[3,0,13,125,21]
+"classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[3,0,13,125,25]
 };
