@@ -1,5 +1,7 @@
 var NAVTREEINDEX92 =
 {
+"classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[4,0,9,143,15],
+"classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[3,0,13,181,14],
 "classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[4,0,9,143,14],
 "classzyppng_1_1ZckHelper.html":[3,0,13,182],
 "classzyppng_1_1ZckHelper.html":[4,0,9,144],
@@ -247,7 +249,5 @@ var NAVTREEINDEX92 =
 "classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[4,0,9,6,4,12],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[3,0,13,44,4,8],
 "classzyppng_1_1worker_1_1DeviceDriver.html#a071555e42d58c5d6465a34fb1d76d2be":[4,0,9,6,4,8],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[3,0,13,44,4,18],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[4,0,9,6,4,18],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0c5809959f78dacfb22be9f4eb86ba8f":[3,0,13,44,4,3]
+"classzyppng_1_1worker_1_1DeviceDriver.html#a0be42c0d96bd73b23323d1d3cb0f9fef":[3,0,13,44,4,18]
 };
