@@ -1,5 +1,7 @@
 var NAVTREEINDEX99 =
 {
+"namespacezypp_1_1base_1_1logger.html#a63b33f7b4a4574b199cdc69dc466b7e5":[3,0,10,2,0,4],
+"namespacezypp_1_1base_1_1logger.html#a78588c13059f348407d74d5eb86904e7":[3,0,10,2,0,3],
 "namespacezypp_1_1base_1_1logger.html#a78588c13059f348407d74d5eb86904e7a0ea593e7097a3bb9cc02f324305d53e2":[3,0,10,2,0,3,5],
 "namespacezypp_1_1base_1_1logger.html#a78588c13059f348407d74d5eb86904e7a6ccd02070382fd265ad1decad6012721":[3,0,10,2,0,3,4],
 "namespacezypp_1_1base_1_1logger.html#a78588c13059f348407d74d5eb86904e7a782b77c706bd48920a44423f7955a922":[3,0,10,2,0,3,0],
@@ -39,6 +41,7 @@ var NAVTREEINDEX99 =
 "namespacezypp_1_1env.html#a431f186e64a875e2323dc68a9d27438b":[3,0,10,7,7],
 "namespacezypp_1_1env.html#a44ac5e5995923d4d078e0cd036ccb357":[3,0,10,7,10],
 "namespacezypp_1_1env.html#a4afff5bd7986ed5db57c297e7aad1702":[3,0,10,7,11],
+"namespacezypp_1_1env.html#a516fcc088e11b622eb7079018fea9886":[3,0,10,7,13],
 "namespacezypp_1_1env.html#a6d32234b50d31d7cfd3bdefc6f2d0753":[3,0,10,7,12],
 "namespacezypp_1_1env.html#aa53d6868a565091840faaa20c6ed701b":[3,0,10,7,6],
 "namespacezypp_1_1env.html#aaf04c7a3a091ff1eaab086ff0a183fdb":[3,0,10,7,5],
@@ -246,8 +249,5 @@ var NAVTREEINDEX99 =
 "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa4f27de733f41d8de8c96ad59ea0c7f4":[3,0,10,25,92,2],
 "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa8760d7c86915746134252e4a65751e5":[3,0,10,25,92,1],
 "namespacezypp_1_1media.html#a4b8d0b917dd34b743c9109cf4b60cff6":[3,0,10,25,83],
-"namespacezypp_1_1media.html#a53d8e91988bfcdd2c45653715031aa5f":[3,0,10,25,88],
-"namespacezypp_1_1media.html#a5e0f31d7fbf79da2e20f076c1a1031eb":[3,0,10,25,103],
-"namespacezypp_1_1media.html#a5e756833b1c7344b64e11041cd1384e7":[3,0,10,25,102],
-"namespacezypp_1_1media.html#a62325afdd62526c64131928b8aa33c30":[3,0,10,25,112]
+"namespacezypp_1_1media.html#a53d8e91988bfcdd2c45653715031aa5f":[3,0,10,25,88]
 };
